==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/RingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingDescriptionMetadata } from "./RingDescriptionMetadata";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingSeriesDescription } from "./RingSeriesDescription";
/**
 * @hidden
 */
export let RingSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RingSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RingSeriesDescriptionMetadata.a == null) {
                RingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RingSeriesDescriptionMetadata.c(RingSeriesDescriptionMetadata.a);
            }
            if (a.k(RingSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(RingSeriesDescriptionMetadata.a);
            RingDescriptionMetadata.d(a);
        }
        static c(a) {
            RingSeriesBaseDescriptionMetadata.c(a);
            a.item("Ring", "ExportedType:Ring");
        }
        static d(a) {
            RingSeriesDescriptionMetadata.b(a);
            a.ad("RingSeries", () => new RingSeriesDescription());
            a.ac("RingSeries", RingSeriesDescriptionMetadata.a);
        }
    }
    RingSeriesDescriptionMetadata.$t = markType(RingSeriesDescriptionMetadata, 'RingSeriesDescriptionMetadata');
    RingSeriesDescriptionMetadata.a = null;
    return RingSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/RingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingDescriptionMetadata } from "./RingDescriptionMetadata";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingSeriesDescription } from "./RingSeriesDescription";
/**
 * @hidden
 */
export let RingSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RingSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RingSeriesDescriptionMetadata.a == null) {
                RingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RingSeriesDescriptionMetadata.c(RingSeriesDescriptionMetadata.a);
            }
            if (a.k(RingSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(RingSeriesDescriptionMetadata.a);
            RingDescriptionMetadata.d(a);
        }
        static c(a) {
            RingSeriesBaseDescriptionMetadata.c(a);
            a.item("Ring", "ExportedType:Ring");
        }
        static d(a) {
            RingSeriesDescriptionMetadata.b(a);
            a.ae("RingSeries", () => new RingSeriesDescription());
            a.ad("RingSeries", RingSeriesDescriptionMetadata.a);
        }
    }
    RingSeriesDescriptionMetadata.$t = markType(RingSeriesDescriptionMetadata, 'RingSeriesDescriptionMetadata');
    RingSeriesDescriptionMetadata.a = null;
    return RingSeriesDescriptionMetadata;
})();
